summaryrefslogtreecommitdiff
path: root/Lib/test/test_largefile.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_largefile.py')
-rw-r--r--Lib/test/test_largefile.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_largefile.py b/Lib/test/test_largefile.py
index 1c6297ac7c..7502dc3c82 100644
--- a/Lib/test/test_largefile.py
+++ b/Lib/test/test_largefile.py
@@ -14,7 +14,7 @@ try:
import signal
# The default handler for SIGXFSZ is to abort the process.
# By ignoring it, system calls exceeding the file size resource
# limit will raise IOError instead of crashing the interpreter.
oldhandler = signal.signal(signal.SIGXFSZ, signal.SIG_IGN)
except (ImportError, AttributeError):
pass
@@ -162,7 +162,7 @@ def test_main():
# flush, too!
f.write(b'x')
f.flush()
- except (IOError, OverflowError):
+ except (OSError, OverflowError):
f.close()
unlink(TESTFN)
raise unittest.SkipTest("filesystem does not have largefile support")
@@ -14,7 +14,7 @@ try:
# The default handler for SIGXFSZ is to abort the process.
# By ignoring it, system calls exceeding the file size resource
- # limit will raise IOError instead of crashing the interpreter.
+ # limit will raise OSError instead of crashing the interpreter.
oldhandler = signal.signal(signal.SIGXFSZ, signal.SIG_IGN)
except (ImportError, AttributeError):